'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
var useMathRandomBasedImplementation = void 0;

if (typeof crypto === 'undefined') {
  try {
    require('crypto');
    useMathRandomBasedImplementation = false;
  } catch (e) {
    useMathRandomBasedImplementation = true;
  }
} else {
  useMathRandomBasedImplementation = false;
}

var ALPHANUM = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
var idGenerator = void 0;

if (useMathRandomBasedImplementation) {
  idGenerator = function idGenerator() {
    var length = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 15;

    var id = '';

    for (var i = 0; i < length; i++) {
      id += ALPHANUM.charAt(Math.floor(Math.random() * ALPHANUM.length));
    }

    return id;
  };
} else {
  (function () {
    var _require = require('crypto'),
        randomBytes = _require.randomBytes;

    idGenerator = function idGenerator(length) {
      var id = '';

      var random = randomBytes(length);

      var cursor = 0;
      for (var i = 0; i < length; i += 1) {
        cursor += random[i];
        id += ALPHANUM[cursor % ALPHANUM.length];
      }

      return id;
    };
  })();
}

exports.default = function () {
  var length = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 15;

  if (length < 1) {
    throw new Error('Ids must be at least one character long');
  }

  return idGenerator(length);
};